fluorflow library

Main library for the fluorflow package.

Classes

BaseViewModel
Base viewmodel that implements ViewModel and ChangeNotifier. Provides basic functionality for other view models and for the usage with views.
BottomToTopFadePageRouteBuilder
A custom page route builder that provides a bottom to top fade transition effect.
BottomToTopPageRouteBuilder
A custom page route builder that provides a bottom to top transition effect.
DataViewModel<TData>
"Data" view model. Contains a data of type TData object that is observed for changes. This view model is used to manage complex data operations and to notify the UI when the data changes. The data can be of any type and is stored in a ValueNotifier. The data must be initialized with a default value (synchronously) and can be changed at any time. To initialize data with an asynchronous operation, the initialize method can be overridden.
FadeInPageRouteBuilder
A custom page route builder that provides a fade-in transition effect.
FluorFlowBottomSheet<TResult, TViewModel extends ViewModel>
An abstract base class for FluorFlow bottom sheets.
FluorFlowDialog<TResult, TViewModel extends ViewModel>
An abstract base class for FluorFlow dialogs.
FluorFlowSimpleBottomSheet<TResult>
A base class for creating simple bottom sheets in FluorFlow.
FluorFlowSimpleDialog<TResult>
Base class for creating simple dialogs in FluorFlow.
FluorFlowView<TViewModel extends ViewModel>
Base class for a view that is managed by a ViewModel. The view model is created when the view is initialized and disposed when the view is disposed.
LeftToRightFadePageRouteBuilder
A custom page route builder that provides a left to right fade transition effect.
LeftToRightPageRouteBuilder
A custom page route builder that provides a left to right transition effect.
A service that provides a set of methods to navigate between routes. One may directly use the navigateTo and other methods to navigate dynamically. However, in combination with the fluorflow_generator, convenience methods are created as method extensions for this service.
NoTransitionPageRouteBuilder
A custom page route builder that provides a page transition without any animation.
PlatformPageRouteBuilder
A custom page route builder that provides transitions that should match the defaults of the underlying platform.
RightToLeftFadePageRouteBuilder
A custom page route builder that provides a right to left fade transition effect.
RightToLeftPageRouteBuilder
A custom page route builder that provides a right to left transition effect.
TopToBottomFadePageRouteBuilder
A custom page route builder that provides a top to bottom fade transition effect.
TopToBottomPageRouteBuilder
A custom page route builder that provides a top to bottom transition effect.
ZoomInPageRouteBuilder
A custom page route builder that provides a zoom-in transition effect.

Extensions

CompleterExtensions on OverlayCompleter<T>
A set of extensions for OverlayCompleter.

Properties

locator → GetIt
The global locator instance.
final

Functions

generateRouteFactory(RouteMap map) RouteFactory
Create a route factory for a given route map.

Typedefs

Locator = GetIt
Alias for GetIt. This is the dependency locator (container) for the app.
OverlayCompleter<T> = void Function({bool? confirmed, T? result})
Function / Callback type for completing overlays. Overlays are dialogs, bottom sheets, snackbars, etc.
RouteMap = Map<String, RouteFactory>
Map that contains a set of routes (by name) and their corresponding route factories.